/**
 * Select text between two wrapper characters and open it as a file.
 *
 * @category  WeBuilder Plugin
 * @package   OPEN ABSOLUTE PATH
 * @author    Dominique De Bisschop (Thanks to Peter Klein for a base of his plugin "SELECT BETWEEN"
 * @copyright 2016
 * @license   http://www.freebsd.org/copyright/license.html  BSD License
 * @version   1.01
 */

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *     29   function SelectBetwenSingleDoubleQuotes()
 *     42   function SelectBetween(startChar, endChar)
 *     84   function openCursorFile(pathFile)
 *     98   function OnInstalled()
 *
 * TOTAL FUNCTIONS: 4
 * (This index is automatically created/updated by the WeBuilder plugin "DocBlock Comments")
 *
 */

/**
 * Select between single or double quotes
 *
 * @return void
 */
function SelectBetwenSingleDoubleQuotes() {
    SelectBetween("['\"]","['\"]");
}


/**
 * Select text between two wrapper charcters
 *
 * @param  string   startChar
 * @param  string   endChar
 *
 * @return void
 */
function SelectBetween(startChar, endChar) {
    var text = Editor.Text;

    // Convert line/column format into text position
    Editor.CursorPosToTextPos(Editor.Selection.SelStartColReal, Editor.Selection.SelStartLine, textPos);

    // Test if we can find the startChar at the left side of the cursor position
    var leftContent = Copy(text, 0, textPos);
    if (RegexMatchAll(leftContent, "[\\s\\S]*" + startChar + "(?=[^" + startChar + "]*)", true, match, p) == true) {

        var startPos = Length(_v(match, [0, 0]));

        // Test if we can find the endChar at the right side of the cursor position
        if (RegexMatchAll(Copy(text, textPos + 1, Length(text)), "[^" + endChar + "]*(" + endChar + ")", true, match, p) == true) {

            var endPos = Length(leftContent) + _v(p, [0, 1]) - 1;

            // Convert text positions into lines/columns format
            Editor.TextPosToCursorPos(startPos, startX, startY);
            Editor.TextPosToCursorPos(endPos, endX, endY);

            // Make selection
            var Sel = Editor.Selection;
            Sel.SelStartLine = startY;
            Sel.SelStartCol = startX;
            Sel.SelEndLine = endY;
            Sel.SelEndCol = endX;

            Editor.Selection = Sel;
            var pathFile = Editor.SelText;
            var pathBegin = copy(pathFile, 0, 1);

            if (pathBegin == "/") {
                openCursorFile(Script.ProjectSettings.SelectedProjectRoot + pathFile);
            } else {
                openCursorFile(ExtractFilePath(Document.FileName) + pathFile);
            }
        }
    }
}

function openCursorFile (pathFile) {
  pathFile = RegexReplace(pathFile, "/","\\", true);
  if (FileExists(pathFile)) {
    Documents.OpenDocument(pathFile);
  } else {
    alert("Impossible to open this file");
  }
}

/**
 * Show info when plugin is installed.
 *
 * @return void
 */
function OnInstalled() {
  Alert("Open Absolute Path 1.01 by Dominique De Bisschop installed sucessfully!");
}

Script.ConnectSignal("installed", "OnInstalled");

var bmp = new TBitmap;

var act1 = Script.RegisterDocumentAction("", "Open this file", "", "SelectBetwenSingleDoubleQuotes");
LoadFileToBitmap(Script.Path + "icone.png", bmp);
Actions.SetIcon(act1, bmp);

delete bmp;